@@ -16,18 +16,18 @@ class EsRequest:
         # 密码
         self.password = password
         try:
-            httpx = importlib.import_module("httpx")
+            request = importlib.import_module("lesscode_utils.request")
         except ImportError as e:
-            raise Exception(f"httpx is not exist,run:pip install httpx==0.24.1")
-        self.auth = httpx.BasicAuth(user, password)
+            raise Exception(f"lesscode_utils is not exist,run:pip install lesscode_utils")
+        self.auth = request.get_basic_auth(user, password)
         host_str = host.split(",")
         self.hosts = [host for host in host_str]
 
     def es_selector_way(self, url_func_str, param_dict, find_condition=None, request_way="post"):
-        if request_way == "get":
-            request_way = self.format_es_get
-        else:
-            request_way = self.format_es_post
+        try:
+            request = importlib.import_module("lesscode_utils.request")
+        except ImportError as e:
+            raise Exception(f"lesscode_utils is not exist,run:pip install lesscode_utils")
         res = None
         # 随机打乱列表
         random.shuffle(self.hosts)
@@ -36,14 +36,18 @@ class EsRequest:
             param_dict["port"] = self.port
             url = url_func_str(**param_dict)
             try:
-                res = request_way(url, find_condition)
-                if res.get("took"):
-                    break
+                if request_way == "get":
+                    res = request.sync_common_get(url, params=find_condition, result_type="json", auth=self.auth)
+                elif request_way == "post":
+                    res = request.sync_common_post(url, json=find_condition, result_type="json", auth=self.auth)
+                if res:
+                    if res.get("took"):
+                        break
             except:
                 continue
         return res
 
-    def format_es_post(self, url, body, params=None):
+    def format_es_request(self, url, methd: str, body, params=None):
         """
         发送http请求
         :param params:
@@ -52,83 +56,27 @@ class EsRequest:
         :return:
         """
         try:
-            httpx = importlib.import_module("httpx")
+            request = importlib.import_module("lesscode_utils.request")
         except ImportError as e:
-            raise Exception(f"httpx is not exist,run:pip install httpx==0.24.1")
-        r = httpx.post(
-            url,
-            json=body,
-            headers={'content-type': "application/json"},
-            params=params,
-            auth=self.auth,
-            timeout=None
-        )
-        res = r.json()
-        return res
-
-    def format_es_put(self, url, body, params=None):
-        """
-        发送http请求
-        :param params:
-        :param url:
-        :param body:
-        :return:
-        """
-        try:
-            httpx = importlib.import_module("httpx")
-        except ImportError as e:
-            raise Exception(f"httpx is not exist,run:pip install httpx==0.24.1")
-        r = httpx.put(
-            url,
-            params=params,
-            json=body,
-            headers={'content-type': "application/json"},
-            auth=self.auth,
-            timeout=None
-        )
-        res = r.json()
-        return res
-
-    def format_es_get(self, url, params=None):
-        """
-        发送http请求
-        :param params:
-        :param url:
-        :return:
-        """
-        try:
-            httpx = importlib.import_module("httpx")
-        except ImportError as e:
-            raise Exception(f"httpx is not exist,run:pip install httpx==0.24.1")
-        r = httpx.get(
-            url,
-            params=params,
-            headers={'content-type': "application/json"},
-            auth=self.auth,
-            timeout=None
-        )
-        res = r.json()
-        return res
-
-    def format_es_delete(self, url, params=None):
-        """
-        发送http请求
-        :param params:
-        :param url:
-        :return:
-        """
-        try:
-            httpx = importlib.import_module("httpx")
-        except ImportError as e:
-            raise Exception(f"httpx is not exist,run:pip install httpx==0.24.1")
-        r = httpx.delete(
-            url,
-            params=params,
-            headers={'content-type': "application/json"},
-            auth=self.auth,
-            timeout=None
-        )
-        res = r.json()
+            raise Exception(f"lesscode_utils is not exist,run:pip install lesscode_utils")
+        res = None
+        if methd.lower() == "post":
+            res = request.sync_common_post(url, json=body, params=params, headers={'content-type': "application/json"},
+                                           result_type="json",
+                                           auth=self.auth, timeout=None)
+        elif methd.lower() == "get":
+            res = request.sync_common_get(url, json=body, params=params, headers={'content-type': "application/json"},
+                                          result_type="json",
+                                          auth=self.auth, timeout=None)
+        elif methd.lower() == "put":
+            res = request.sync_common_put(url, json=body, params=params, headers={'content-type': "application/json"},
+                                          result_type="json",
+                                          auth=self.auth, timeout=None)
+        elif methd.lower() == "delete":
+            res = request.sync_common_delete(url, json=body, params=params,
+                                             headers={'content-type': "application/json"},
+                                             result_type="json",
+                                             auth=self.auth, timeout=None)
         return res
 
     def format_scroll_url(self, host=None, port=None, route_key=None, scroll=None):
