@@ -41,6 +41,7 @@ def deal_cache(func, ex, cache_key, *args, **params):
     func_name = str(func).split(" ")[1]
     if not cache_key:
         cache_key = format_insert_key(signature, func_name, args, params)
+    logging.info("redis_key:{}".format(cache_key))
     value = query_cache(cache_key, params, ex, func=func, args=args)
     if value is not False:
         data = value
@@ -62,7 +63,7 @@ def query_cache(cache_key, params=None, ex=3600 * 12, func=None, args=None, conn
     if options.cache_enable:
         ttl = RedisHelper(conn_name).get_connection(sync=True).ttl(cache_key)
 
-        if ttl and 0 < ttl <= 3600 * 11 + 2700:
+        if ttl and ex >= 900 and 0 < ttl <= ex - 900:
             Thread(target=request_interface, kwargs={
                 "func": func,
                 "params": params,
